# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.collection_version_search_list_response import CollectionVersionSearchListResponse

class TestCollectionVersionSearchListResponse(unittest.TestCase):
    """CollectionVersionSearchListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CollectionVersionSearchListResponse:
        """Test CollectionVersionSearchListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CollectionVersionSearchListResponse`
        """
        model = CollectionVersionSearchListResponse()
        if include_optional:
            return CollectionVersionSearchListResponse(
                repository = pulpcore.client.pulp_ansible.models.repository_response.RepositoryResponse(
                    pulp_href = '', 
                    prn = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    versions_href = '', 
                    pulp_labels = {
                        'key' : ''
                        }, 
                    latest_version_href = '', 
                    name = '', 
                    description = '', 
                    retain_repo_versions = 1, 
                    remote = '', ),
                collection_version = pulpcore.client.pulp_ansible.models.collection_summary_response.CollectionSummaryResponse(
                    pulp_href = '', 
                    namespace = '', 
                    name = '', 
                    version = '', 
                    requires_ansible = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    contents = [
                        null
                        ], 
                    dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                    description = '', 
                    tags = [
                        pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                            name = '', )
                        ], ),
                repository_version = '',
                namespace_metadata = pulpcore.client.pulp_ansible.models.ansible/ansible_namespace_metadata_response.ansible.AnsibleNamespaceMetadataResponse(
                    pulp_href = '', 
                    name = 'jUtgswwmejtcmosllnyulewqtzioitixmooyscslvdntrddzxydswqltrttwkqzbunjxbelktnh7nzn3yp7d8tmo8zxed012', 
                    company = '', 
                    email = '', 
                    description = '', 
                    resources = '', 
                    links = [
                        pulpcore.client.pulp_ansible.models.namespace_link_response.NamespaceLinkResponse(
                            url = '', 
                            name = '', )
                        ], 
                    avatar_sha256 = '', 
                    avatar_url = '', 
                    metadata_sha256 = '', ),
                is_highest = True,
                is_deprecated = True,
                is_signed = True
            )
        else:
            return CollectionVersionSearchListResponse(
                repository = pulpcore.client.pulp_ansible.models.repository_response.RepositoryResponse(
                    pulp_href = '', 
                    prn = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    versions_href = '', 
                    pulp_labels = {
                        'key' : ''
                        }, 
                    latest_version_href = '', 
                    name = '', 
                    description = '', 
                    retain_repo_versions = 1, 
                    remote = '', ),
                collection_version = pulpcore.client.pulp_ansible.models.collection_summary_response.CollectionSummaryResponse(
                    pulp_href = '', 
                    namespace = '', 
                    name = '', 
                    version = '', 
                    requires_ansible = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    contents = [
                        null
                        ], 
                    dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                    description = '', 
                    tags = [
                        pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                            name = '', )
                        ], ),
                namespace_metadata = pulpcore.client.pulp_ansible.models.ansible/ansible_namespace_metadata_response.ansible.AnsibleNamespaceMetadataResponse(
                    pulp_href = '', 
                    name = 'jUtgswwmejtcmosllnyulewqtzioitixmooyscslvdntrddzxydswqltrttwkqzbunjxbelktnh7nzn3yp7d8tmo8zxed012', 
                    company = '', 
                    email = '', 
                    description = '', 
                    resources = '', 
                    links = [
                        pulpcore.client.pulp_ansible.models.namespace_link_response.NamespaceLinkResponse(
                            url = '', 
                            name = '', )
                        ], 
                    avatar_sha256 = '', 
                    avatar_url = '', 
                    metadata_sha256 = '', ),
                is_highest = True,
                is_deprecated = True,
                is_signed = True,
        )
        """

    def testCollectionVersionSearchListResponse(self):
        """Test CollectionVersionSearchListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
