# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_api import PulpAnsibleDefaultApiV3CollectionsApi


class TestPulpAnsibleDefaultApiV3CollectionsApi(unittest.TestCase):
    """PulpAnsibleDefaultApiV3CollectionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PulpAnsibleDefaultApiV3CollectionsApi()

    def tearDown(self) -> None:
        pass

    def test_delete(self) -> None:
        """Test case for delete

        """
        pass

    def test_list(self) -> None:
        """Test case for list

        """
        pass

    def test_read(self) -> None:
        """Test case for read

        """
        pass

    def test_update(self) -> None:
        """Test case for update

        """
        pass


if __name__ == '__main__':
    unittest.main()
